@@ -70,23 +70,24 @@ def get_default_config_file_path():
 
 
 def update_config_list_to_dict(items: list):
-    """
-    Given the path/name and value pairs in the items list, build a dict
+    """Given the path/name and value pairs in the items list, build a dict
     with all config values represented by items.
 
-        i.e.,
-            given items=[("a.b.c","1"), ("a.e.f","2")]
-            return {
-                "a": {
-                    "b": {
-                        "c": "1"
-                    }
-                    "e": {
-                        "f": "2"
-                    }
+    Example::
+
+        given items=[("a.b.c","1"), ("a.e.f","2")]
+        return {
+            "a": {
+                "b": {
+                    "c": "1"
+                }
+                "e": {
+                    "f": "2"
                 }
             }
-    """
+        }
+
+"""
     if not isinstance(items, list):
         raise ValueError(f"The items parameter must be a list")
     if not isinstance(items[0], tuple):
@@ -231,9 +232,11 @@ def is_storage_def_name_ok(storage_def_name):
 
 def is_existing_filesystem_storage_path(storage_location: str):
     """An existing valid filesystem storage path has the following characteristics:
-    - It exists as a directory.
-    - It is specified as an absolute path. (For no other reason than to ensure the
-      user specifies something explicit/clear.)
+
+        It exists as a directory.
+
+        It is specified as an absolute path. (For no other reason than to ensure the user specifies
+            something explicit/clear.)
     """
     return os.path.isdir(storage_location) and is_absolute_path(storage_location)
 
